@@ -1,10 +1,16 @@
 from __future__ import annotations
 
+import asyncio
+
 
 class CacheError(Exception):
     """ Common base exception """
 
 
+class NetworkTimeoutError(asyncio.TimeoutError, CacheError):
+    """ Timed out while waiting on a network request """
+
+
 class CacheRedisError(CacheError):
     """ Redis communication failure """
 
